pub fn init_config()Expand description
Create chobs.json config file. If you already have this file, it will be overwritten.
use chobs::init_config;
fn main() {
init_config();
}pub fn init_config()Create chobs.json config file. If you already have this file, it will be overwritten.
use chobs::init_config;
fn main() {
init_config();
}